# Dominant Color Recognizer



## General info
DCR is a Python library created to obtain a specific number of dominant colors from image.
You can define number of colors and color model in which values will be returned.

Currently supported color models:
| Color model  | Example         |
|--------------|-----------------|
|    HEX       | #0040ff         |
|    RGB       | rgb(0, 64, 255) |


## Instalation

Use the package manager [pip](https://pip.pypa.io/en/stable/getting-started/) to install DCR library:
```commandline
pip install dominantcolorrecognizer
```
